/***************************************
 *                                     *
 *  JBoss: The OpenSource J2EE WebOS   *
 *                                     *
 *  Distributable under LGPL license.  *
 *  See terms of license at gnu.org.   *
 *                                     *
 ***************************************/

package org.jboss.monitor;

import javax.management.MalformedObjectNameException;

import org.jboss.system.ServiceMBean;

import org.w3c.dom.Element;

/**
 * This is the management interface of the LoggingMonitor service which provides
 * the ability to create monitoring logs for various MBeans and their
 * attributes.
 */
public interface LoggingMonitorMBean extends ServiceMBean {

    /**
     * Retrieves the name of the file to which this monitor's information will
     * be logged.
     */
    String getFilename();

    /**
     * Sets the name of the file to which this monitor's information will be
     * logged.
     */
    void setFilename(String filename);

    /**
     * Retrieves whether or not this monitor's log file should have information
     * appended to it, if it already exists.
     */
    boolean getAppendToFile();

    /**
     * Sets whether or not this monitor's log file should have information
     * appended to it, if it already exists.
     */
    void setAppendToFile(boolean appendToFile);

    /**
     * Sets the monitored objects configuration.
     *
     * @param monitoredObjects the objects to be monitored specified in the
     * following format:
     * <pre>
     * &lt;attribute name="MonitoredObjects"&gt;
     *   &lt;configuration&gt;
     *      &lt;monitoredmbean name="[object name]" logger="[logger name]"&gt;
     *         &lt;attribute&gt;[attribute name]&lt;/attribute&gt;
     *         &lt;attribute&gt;[attribute name]&lt;/attribute&gt;
     *         ...
     *      &lt;/monitoredmbean&gt;
     *   &lt;/configuration&gt;
     * &lt;/attribute&gt;
     * </pre>
     *
     * @throws MalformedObjectNameException if the monitored objects
     *                                      configuration contains an invalid
     *                                      object name.
     */
    void setMonitoredObjects(Element monitoredObjects)
    throws MalformedObjectNameException;

    /**
     * Retrieves the period to delay between monitoring snapshots.
     */
    long getMonitorPeriod();

    /**
     * Sets the period to delay between monitoring snapshots.
     */
    void setMonitorPeriod(long monitorPeriod);
}
