/***************************************
 *                                     *
 *  JBoss: The OpenSource J2EE WebOS   *
 *                                     *
 *  Distributable under LGPL license.  *
 *  See terms of license at gnu.org.   *
 *                                     *
 ***************************************/

package org.jboss.monitor;

import javax.management.JMException;

import org.apache.log4j.Logger;

import java.util.TimerTask;

/**
 * This class provides a repeatable task for monitoring to be executed by a
 * timer.
 */
class LoggingMonitorTimerTask extends TimerTask
{
    private MonitoredMBean[] _monitoredObjects;

    /**
     * Constructor.
     *
     * @param monitoredObjects the objects to be monitored.
     */
    public LoggingMonitorTimerTask(MonitoredMBean[] monitoredObjects)
    {
        _monitoredObjects = monitoredObjects;

        for (int i = 0; i < monitoredObjects.length; ++i)
        {
            monitoredObjects[i].logFormat();
        }
    }

    /*
     * TimerTask implementation.
     */

    public void run()
    {
        for (int i = 0; i < _monitoredObjects.length; ++i)
        {
            try
            {
                _monitoredObjects[i].logAttributes();
            }
            catch (JMException jme)
            {
                Logger logger = Logger.getLogger(getClass());
                logger.error("Unable to log MBean attributes:", jme);
            }
        }
    }
}

